@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -41,9 +41,13 @@
 #ifndef NBDKIT_VECTOR_H
 #define NBDKIT_VECTOR_H
 
+#include <stdbool.h>
 #include <assert.h>
 #include <string.h>
 
+#include "compiler-macros.h"
+#include "static-assert.h"
+
 #ifdef __clang__
 #pragma clang diagnostic ignored "-Wunused-function"
 #pragma clang diagnostic ignored "-Wduplicate-decl-specifier"
@@ -52,13 +56,18 @@
 /* Use of this macro defines a new type called ‘name’ containing an
  * extensible vector of ‘type’ elements.  For example:
  *
- *   DEFINE_VECTOR_TYPE(string_vector, char *)
+ *   DEFINE_VECTOR_TYPE (string_vector, char *);
  *
  * defines a new type called ‘string_vector’ as a vector of ‘char *’.
  * You can create variables of this type:
  *
  *   string_vector names = empty_vector;
  *
+ * or
+ *
+ *   string_vector names;
+ *   names = (string_vector)empty_vector;
+ *
  * where ‘names.ptr[]’ will be an array of strings and ‘names.len’
  * will be the number of strings.  There are no get/set accessors.  To
  * iterate over the strings you can use the ‘.ptr’ field directly:
@@ -66,7 +75,8 @@
  *   for (size_t i = 0; i < names.len; ++i)
  *     printf ("%s\n", names.ptr[i]);
  *
- * Initializing with ‘empty_vector’ sets ‘.ptr = NULL’ and ‘.len = 0’.
+ * Initializing with ‘empty_vector’, or assigning the compound literal
+ * ‘(string_vector)empty_vector’, sets ‘.ptr = NULL’ and ‘.len = 0’.
  *
  * DEFINE_VECTOR_TYPE also defines utility functions.  For the full
  * list see the definition below, but useful functions include:
@@ -94,17 +104,28 @@
    * allocated and capacity is increased, but the vector length is      \
    * not increased and the new elements are not initialized.            \
    */                                                                   \
-  static inline int                                                     \
+  static inline int __attribute__ ((__unused__))                        \
   name##_reserve (name *v, size_t n)                                    \
   {                                                                     \
     return generic_vector_reserve ((struct generic_vector *)v, n,       \
-                                   sizeof (type));                      \
+                                   sizeof (type), false);               \
+  }                                                                     \
+                                                                        \
+  /* Same as _reserve, but reserve exactly this number of elements      \
+   * without any overhead.  Useful if you know ahead of time that you   \
+   * will never need to extend the vector.                              \
+   */                                                                   \
+  static inline int __attribute__ ((__unused__))                        \
+  name##_reserve_exactly (name *v, size_t n)                            \
+  {                                                                     \
+    return generic_vector_reserve ((struct generic_vector *)v,          \
+                                   n, sizeof (type), true);             \
   }                                                                     \
                                                                         \
   /* Same as _reserve, but the allocation will be page aligned.  Note   \
    * that the machine page size must be divisible by sizeof (type).     \
    */                                                                   \
-  static inline int                                                     \
+  static inline int __attribute__ ((__unused__))                        \
   name##_reserve_page_aligned (name *v, size_t n)                       \
   {                                                                     \
     return generic_vector_reserve_page_aligned ((struct generic_vector *)v, \
@@ -112,7 +133,7 @@
   }                                                                     \
                                                                         \
   /* Insert at i'th element.  i=0 => beginning  i=len => append */      \
-  static inline int                                                     \
+  static inline int __attribute__ ((__unused__))                        \
   name##_insert (name *v, type elem, size_t i)                          \
   {                                                                     \
     assert (i <= v->len);                                               \
@@ -126,14 +147,14 @@
   }                                                                     \
                                                                         \
   /* Append a new element to the end of the vector. */                  \
-  static inline int                                                     \
+  static inline int __attribute__ ((__unused__))                        \
   name##_append (name *v, type elem)                                    \
   {                                                                     \
     return name##_insert (v, elem, v->len);                             \
   }                                                                     \
                                                                         \
   /* Remove i'th element.  i=0 => beginning  i=len-1 => end */          \
-  static inline void                                                    \
+  static inline void __attribute__ ((__unused__))                       \
   name##_remove (name *v, size_t i)                                     \
   {                                                                     \
     assert (i < v->len);                                                \
@@ -142,7 +163,7 @@
   }                                                                     \
                                                                         \
   /* Remove all elements and deallocate the vector. */                  \
-  static inline void                                                    \
+  static inline void __attribute__ ((__unused__))                       \
   name##_reset (name *v)                                                \
   {                                                                     \
     free (v->ptr);                                                      \
@@ -151,7 +172,7 @@
   }                                                                     \
                                                                         \
   /* Iterate over the vector, calling f() on each element. */           \
-  static inline void                                                    \
+  static inline void __attribute__ ((__unused__))                       \
   name##_iter (name *v, void (*f) (type elem))                          \
   {                                                                     \
     size_t i;                                                           \
@@ -160,26 +181,78 @@
   }                                                                     \
                                                                         \
   /* Sort the elements of the vector. */                                \
-  static inline void                                                    \
+  static inline void __attribute__ ((__unused__))                       \
   name##_sort (name *v,                                                 \
                int (*compare) (const type *p1, const type *p2))         \
   {                                                                     \
-    qsort (v->ptr, v->len, sizeof (type), (void *) compare);            \
+    qsort (v->ptr, v->len, sizeof (type), (void *)compare);             \
   }                                                                     \
                                                                         \
   /* Search for an exactly matching element in the vector using a       \
    * binary search.  Returns a pointer to the element or NULL.          \
    */                                                                   \
-  static inline type *                                                  \
+  static inline type * __attribute__ ((__unused__))                     \
   name##_search (const name *v, const void *key,                        \
                  int (*compare) (const void *key, const type *v))       \
   {                                                                     \
     return bsearch (key, v->ptr, v->len, sizeof (type),                 \
-                    (void *) compare);                                  \
-  }
+                    (void *)compare);                                   \
+  }                                                                     \
+                                                                        \
+  /* Make a new vector with the same elements. */                       \
+  static inline int __attribute__ ((__unused__))                        \
+  name##_duplicate (name *v, name *copy)                                \
+  {                                                                     \
+    /* Note it's allowed for v and copy to be the same pointer. */      \
+    type *vptr = v->ptr;                                                \
+    type *newptr;                                                       \
+    size_t len = v->len * sizeof (type);                                \
+                                                                        \
+    newptr = malloc (len);                                              \
+    if (newptr == NULL) return -1;                                      \
+    memcpy (newptr, vptr, len);                                         \
+    copy->ptr = newptr;                                                 \
+    copy->len = copy->cap = v->len;                                     \
+    return 0;                                                           \
+  }                                                                     \
+                                                                        \
+  /* End with duplicate declaration, so callers must supply ';'. */     \
+  struct name
 
 #define empty_vector { .ptr = NULL, .len = 0, .cap = 0 }
 
+/* This macro should only be used if:
+ * - the vector contains pointers, and
+ * - the pointed-to objects are:
+ *   - neither const- nor volatile-qualified, and
+ *   - allocated with malloc() or equivalent.
+ */
+#define ADD_VECTOR_EMPTY_METHOD(name)                                  \
+  /* Call free() on each element of the vector, then reset the vector. \
+   */                                                                  \
+  static inline void __attribute__ ((__unused__))                      \
+  name##_empty (name *v)                                               \
+  {                                                                    \
+    size_t i;                                                          \
+    for (i = 0; i < v->len; ++i) {                                     \
+      STATIC_ASSERT (TYPE_IS_POINTER (v->ptr[i]),                      \
+                     _vector_contains_pointers);                       \
+      free (v->ptr[i]);                                                \
+    }                                                                  \
+    name##_reset (v);                                                  \
+  }                                                                    \
+                                                                       \
+  /* Force callers to supply ';'. */                                   \
+  struct name
+
+/* Convenience macro tying together DEFINE_VECTOR_TYPE() and
+ * ADD_VECTOR_EMPTY_METHOD(). Inherit and forward the requirement for a
+ * trailing semicolon from ADD_VECTOR_EMPTY_METHOD() to the caller.
+ */
+#define DEFINE_POINTER_VECTOR_TYPE(name, type) \
+  DEFINE_VECTOR_TYPE (name, type);             \
+  ADD_VECTOR_EMPTY_METHOD (name)
+
 struct generic_vector {
   void *ptr;
   size_t len;
@@ -187,7 +260,8 @@ struct generic_vector {
 };
 
 extern int generic_vector_reserve (struct generic_vector *v,
-                                   size_t n, size_t itemsize);
+                                   size_t n, size_t itemsize,
+                                   bool exactly);
 
 extern int generic_vector_reserve_page_aligned (struct generic_vector *v,
                                                 size_t n, size_t itemsize);
