@@ -159,9 +159,9 @@ let print_callback_wrapper { cbname; cbargs } =
   C.print_cbarg_list ~wrap:true cbargs;
   pr "\n";
   pr "{\n";
-  pr "  // golang isn't const-correct, there will be warnings here:\n";
+  pr "  // golang isn't const-correct, casts avoid warnings here:\n";
   pr "  return %s_callback ((long *)" cbname;
-  C.print_cbarg_list ~types:false ~parens:false cbargs;
+  C.print_cbarg_list ~types:false ~parens:false ~noconst:true cbargs;
   pr ");\n";
   pr "}\n";
   pr "\n";
